<?php 

/*
 * rdelete.php
 *
 * Recursively deletes the specified DN and all of its children
 * Variables that come in as POST vars:
 *  - dn (rawurlencoded)
 *  - server_id
 */

require 'config.php';
require_once 'functions.php';

$encoded_dn = $_POST['dn'];
$dn = stripslashes( rawurldecode( $encoded_dn ) );
$server_id = $_POST['server_id'];

if( ! $dn )
	davedap_error( "You must specify a DN." );

check_server_id( $server_id ) or davedap_error( "Bad server_id: " . htmlentities( $server_id ) );
have_auth_info( $server_id ) or davedap_error( "Not enough information to login to server. Please check your configuration." );
davedap_ldap_connect( $server_id ) or davedap_error( "Could not connect to LDAP server" );

$del_result = davedap_rdelete( $server_id, $dn );

if( $del_result )
{
	// kill the DN from the tree browser session variable and
	// refresh the tree viewer frame (left_frame)

	session_start();
	if( session_is_registered( 'tree' ) )
	{
		$tree = $_SESSION['tree'];

		// does it have children? (it shouldn't, but hey, you never know)	
		if( isset( $tree[$server_id][$dn] ) )
			unset( $tree[$server_id][$dn] );
		
		// search and destroy
		foreach( $tree[$server_id] as $tree_dn => $subtree )
			foreach( $subtree as $key => $sub_tree_dn )
				if( 0 == strcasecmp( $sub_tree_dn, $dn ) ) 
					unset( $tree[$server_id][$tree_dn][$key] );
	}

	$_SESSION['tree'] = $tree;
	session_write_close();

	?>

	<script language="javascript">
		parent.left_frame.location.reload();
	</script>

	Object <b><?php echo htmlentities( utf8_decode( $dn ) ); ?></b> and sub-tree deleted successfully.

	<?php 


} else {
	davedap_error( "Could not delete the object: " . htmlentities( utf8_decode( $dn ) ), ldap_error( $ds ), ldap_errno( $ds ) );
}


exit;


function davedap_rdelete( $server_id, $dn )
{
	$children = get_container_contents( $server_id, $dn );
	global $ds;
	$ds = davedap_ldap_connect( $server_id );

	if( ! is_array( $children ) || count( $children ) == 0 ) {
		//echo "<nobr>Deleting $dn<br />";
		if( ldap_delete( $ds, $dn ) )
			return true;
		else
			echo "Error deleting dn: " . htmlentities( utf8_decode( $dn ) ) . "<br />";
	} else {
		foreach( $children as $child_dn ) {
			davedap_rdelete( $server_id, $child_dn );
		}
		//echo "<nobr>Deleting parent: $dn<br />";
		if( ldap_delete( $ds, $dn ) )
			return true;
		else
			echo "Error deleting dn: " . htmlentities( utf8_decode( $dn ) ) . "<br />";
	}

}
